# 组的可见范围

主体为人、组，最终落实到人，客体为组

可分为管理员在控制台对各组的可见范围 和 普通员工在工作台对各组的可见范围。

## 控制台可见范围
由子管理员的管理范围决定，可参考(/docs/algorithm/manage-scope)

## 工作台可见范围
有以下选项：

- 所有人可见
- 组内可见
- 组内及下属组可见
- 指定人、组可见 (组可见即其组内成员以及子孙组的组内成员可见)
- 所有人不可见

TODO：权限记录形式的说明
TODO: 是否要改得更通用？

## 可见范围的呈现
组对人是否可见的判定结果，只有可见与不可见两种状态。
当呈现给用户时，有三种状态：
- 隐藏
    该组及其子孙组均不可见
- 仅显示组名称
    该组不可见，但其存在某个子孙组可见
- 显示组名称及其组成员
    该组可见
